hypergeo_A_nonpos_int: Hypergeometric functions for integer arguments
Description
Hypergeometric functions for A and/or B being integers
Usage
hypergeo_A_nonpos_int(A, B, C, z, tol = 0)
hypergeo_AorB_nonpos_int(A, B, C, z, tol = 0)
Arguments
A,B,C
Parameters for the hypergeometric function
z
Primary complex argument
tol
tolerance
Details
The point of these functions is that if A and C (or B and C)
are identical nonpositive integers, a warning needs to be given.
Function hypergeo_AorB_nonpos_int() is a convenience wrapper
for hypergeo_A_nonpos_int().
References
M. Abramowitz and I. A. Stegun 1965. Handbook of
mathematical functions. New York: Dover