Learn R Programming

hypergeo (version 1.1-2)

i15.3.6: Helper functions

Description

Helper functions for equations 15.3.6-15.3.9

Usage

i15.3.6(A, B, C)
i15.3.7(A, B, C)
i15.3.8(A, B, C)
i15.3.9(A, B, C)
j15.3.6(A, B, C)
j15.3.7(A, B, C)
j15.3.8(A, B, C)
j15.3.9(A, B, C)

Arguments

A,B,C
Parameters of the hypergeometric function

Details

Functions i15.3.?() return the factors at the beginning of equations 15.3.6-9; functions j15.3.?() check for the appropriate arguments of the gamma function being nonpositive integers

References

M. Abramowitz and I. A. Stegun 1965. Handbook of mathematical functions. New York: Dover

See Also

hypergeo

Examples

Run this code
i15.3.6(1.1, 3.2, pi)

Run the code above in your browser using DataLab